==> tine20-allinone_2020.08.8.tar.bz2: Admin/js/Admin-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0} Instillinger"

, "Search:"
: "Søk:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Viser program {0} - {1} of {2}"

, "No applications to display"
: "Ingen program å vise"

, "Order"
: "Ordre"

, "Name"
: "Navn"

, "Status"
: "Status"

, "Version"
: "Versjon"

, "Confirm"
: "Bekreft"

, "Do you really want to delete the selected groups?"
: "Vil du virkelig slette valgte grupper?"

, "Deleting group(s)..."
: "Sletter gruppe(r)"

, "Failed"
: "Feilet"

, "Some error occurred while trying to delete the group."
: "En feil oppsto ved forsøk på å slette gruppen."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Viser grupper  {0} - {1} of {2}"

, "No groups to display"
: "Ingen grupper å vise"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Beskrivelse"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Feil"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  ""
 ,""

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Avbryt"

, "OK"
: ""

, "Configure store"
: ""

, "Model"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: ""

, "Label"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""
 ,""

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: ""

, "Default ({0})"
: ""

, "Computer Name"
: "PC Navn"

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: "Vennligst vent"

, "Updating Tag"
: "Oppdaterer Overskrift"

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Vennligst rett felene listet."

, "Allowed Contexts"
: "Tillatte Contekster"

, "Context"
: "Contekst"

, "Account Rights"
: "Konto Rettigheter"

, "View"
: "Vis"

, "Use"
: "Bruk"

, "Tag Name"
: "Overskrift Navn"

, "Color"
: "Farge"

, "Transferring {0}..."
: ""

, "Tag"
: ""

, "Add New Tag"
: "Legg til Ny Overskrift"

, "Edit Tag \"{0}\""
: "Rediger Overskrift \"{0}\""

, "Do you really want to delete the selected tags?"
: "Vil du virkelig slette valgte overskrifter?"

, "Deleting tag(s)..."
: "Sletter overskrift(er)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "Viser overskrifter {0} - {1} of {2}"

, "No tags to display"
: "Ingen overskrifter å vise"

, "Usage:&#160;"
: ""

, "Updating Memberships"
: "Oppdaterer Medlemskap"

, "Could not save role."
: "Klarte ikke å lagre rolle."

, "Deleting role..."
: "Sletter rolle..."

, "Some error occurred while trying to delete the role."
: "En feil har oppstått ved forsøk på å slette rollen."

, "Rights"
: "Rettigheter"

, "Members"
: "Medlemmer"

, "Role Name"
: "Rolle Navn"

, "Role"
: ""

, "Add New Role"
: "Legg til Ny Rolle"

, "Edit Role \"{0}\""
: "Rediger Rolle \"{0}\""

, "Do you really want to delete the selected roles?"
: "Vil du virkelig slette valgte roller?"

, "Deleting role(s)..."
: "Sletter rolle(r)..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Viser roller {0} - {1} of {2}"

, "No roles to display"
: "Ingen roller å vise"

, "Access Log, Access Logs"
: [
  ""
 ,""

]
, "Groups"
: "Grupper"

, "Applications"
: "Programmer"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Passordene stemmer ikke!"

, "Passwords match!"
: ""

, "Primary group"
: "Primær gruppe"

, "Unix"
: "Unix"

, "Home Directory"
: "Hjemme Mappe"

, "Login Shell"
: "Logg inn skall"

, "Windows"
: "Windows"

, "Home Drive"
: "Hjemme Stasjon"

, "Login Time"
: "Logg inn Tid"

, "never logged in"
: "aldri logget på"

, "Home Path"
: "Hjemme Sti"

, "Logout Time"
: "Logg ut Tid"

, "never logged off"
: "aldri logget av"

, "Profile Path"
: "Profil Sti"

, "Password Last Set"
: "Passord Sist Satt"

, "never"
: "aldri"

, "Logon Script"
: "Logg inn Skript"

, "Password Can Change"
: "Passord Kan Endres"

, "not set"
: "ikke satt"

, "Password Must Change"
: "Passord Må Endres"

, "Kick Off Time"
: "Utkastelses Tid"

, "Filesystem Quota"
: ""

, "Quota"
: "Kvote"

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Informasjon"

, "Last Login"
: "Siste logg inn"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Legg til en alias adresse..."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Kun Videresending"

, "Password confirmation"
: "Passord bekreftelse"

, "Repeat password"
: "Gjenta passord"

, "Ok"
: "Ok"

, "Account"
: "Konto"

, "First name"
: "For navn"

, "Last name"
: "Etter navn"

, "Login name"
: ""

, "Password"
: "Passord"

, "OpenID"
: "ÅpenID"

, "enabled"
: "aktivert"

, "disabled"
: "deaktivert"

, "expired"
: "Utgått"

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: "Utgår"

, "Visibility"
: "Synlighet"

, "Display in addressbook"
: "Vis i adressebok"

, "Hide from addressbook"
: "Skjul fra adressebok"

, "Saved in Addressbook"
: ""

, "Last login at"
: "Siste logg inn kl"

, "don't know"
: "vet ikke"

, "Last login from"
: "Siste logg inn fra"

, "Password set"
: "Passord satt"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "Fil server"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Bruker"
 ,"Brukere"

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Samba Bruker"
 ,"Samba Brukere"

]
, "Email User, Email Users"
: [
  "E-post Bruker"
 ,"E-Post Brukere"

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Passord endret"

, "Set new password"
: "Sett nytt passord"

, "Please enter the new password:"
: "Vennligst skriv det nye passordet:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Gruppe Navn"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Gruppe Medlemmer"

, "personal"
: ""

, "shared"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""
 ,""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  "PC"
 ,"PC'er"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Roller"

, "Containers"
: ""

, "Shared Tags"
: "Delte Emner"

, "Customfields"
: ""

, "Computers"
: "Datamaskiner"

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Administrator"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP Adresse"

, "Client Type"
: ""

, "Session ID"
: "Sessjons ID"

, "Login Name"
: "Logg inn Navn"

, "Result"
: "Resultat"

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "ugyldig passord"

, "ambiguous username"
: "tvetydig brukernavn"

, "user not found"
: "bruker ikke funnet"

, "failure"
: "feil"

, "success"
: "vellykket"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""




































, "Application"
: ""

, "Group"
: ""

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: ""

, "User"
: "Bruker"

, "Samba User"
: "Samba Bruker"

, "Email User"
: "E-post Bruker"

, "Container"
: ""

, "Computer"
: "PC"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Admin/js/Admin-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""
 ,""

]
, "Application, Applications"
: [
  ""
 ,""

]
, "User, Users"
: [
  "Bruker"
 ,"Brukere"

]
, "Groups"
: "Grupper"

, "Roles"
: "Roller"

, "Applications"
: "Programmer"

, "Containers"
: ""

, "Shared Tags"
: "Delte Emner"

, "Customfields"
: ""

, "Computers"
: "Datamaskiner"

, "Access Log, Access Logs"
: [
  ""
 ,""

]
, "Log"
: ""

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "Administrator"

, "Refresh"
: ""

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: ""

, "Computer Name"
: "PC Navn"

, "Config, Configs"
: [
  ""
 ,""

]
, "Description"
: "Beskrivelse"

, "Name"
: "Navn"

, "Label"
: ""

, "Value"
: ""

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: "Gruppe Navn"

, "Visibility"
: "Synlighet"

, "Display in addressbook"
: "Vis i adressebok"

, "Hide from addressbook"
: "Skjul fra adressebok"

, "Saved in Addressbook"
: ""

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Gruppe Medlemmer"

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Confirm"
: "Bekreft"

, "Do you really want to delete the selected tags?"
: "Vil du virkelig slette valgte overskrifter?"

, "Deleting tag(s)..."
: "Sletter overskrift(er)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Search:"
: "Søk:"

, "Displaying tags {0} - {1} of {2}"
: "Viser overskrifter {0} - {1} of {2}"

, "No tags to display"
: "Ingen overskrifter å vise"

, "ID"
: "ID"

, "Color"
: "Farge"

, "Usage:&#160;"
: ""

, "Do you really want to delete the selected roles?"
: "Vil du virkelig slette valgte roller?"

, "Deleting role(s)..."
: "Sletter rolle(r)..."

, "Failed"
: "Feilet"

, "Some error occurred while trying to delete the role."
: "En feil har oppstått ved forsøk på å slette rollen."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Viser roller {0} - {1} of {2}"

, "No roles to display"
: "Ingen roller å vise"

, "Container Name"
: ""

, "Type"
: ""

, "Container Order"
: ""

, "Container, Containers"
: [
  ""
 ,""

]
, "Model"
: ""

, "personal"
: ""

, "shared"
: ""

, "Order"
: "Ordre"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "Vil du virkelig slette valgte grupper?"

, "Deleting group(s)..."
: "Sletter gruppe(r)"

, "Some error occurred while trying to delete the group."
: "En feil oppsto ved forsøk på å slette gruppen."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Viser grupper  {0} - {1} of {2}"

, "No groups to display"
: "Ingen grupper å vise"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "IP Adresse"

, "Login Time"
: "Logg inn Tid"

, "Logout Time"
: "Logg ut Tid"

, "Client Type"
: ""

, "Session ID"
: "Sessjons ID"

, "Login Name"
: "Logg inn Navn"

, "Result"
: "Resultat"

, "User Agent"
: ""

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "ugyldig passord"

, "ambiguous username"
: "tvetydig brukernavn"

, "user not found"
: "bruker ikke funnet"

, "failure"
: "feil"

, "success"
: "vellykket"

, "Customfield, Customfields"
: [
  ""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "Feil"

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Avbryt"

, "OK"
: ""

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""
 ,""

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Status"
: "Status"

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "Etter navn"

, "First name"
: "For navn"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "ÅpenID"

, "Last login at"
: "Siste logg inn kl"

, "Last login from"
: "Siste logg inn fra"

, "Password Must Change"
: "Passord Må Endres"

, "Password changed"
: "Passord endret"

, "Expires"
: "Utgår"

, "Set new password"
: "Sett nytt passord"

, "Please enter the new password:"
: "Vennligst skriv det nye passordet:"

, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Samba Bruker"
 ,"Samba Brukere"

]
, "Email User, Email Users"
: [
  "E-post Bruker"
 ,"E-Post Brukere"

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Passordene stemmer ikke!"

, "Passwords match!"
: ""

, "Primary group"
: "Primær gruppe"

, "Unix"
: "Unix"

, "Home Directory"
: "Hjemme Mappe"

, "Login Shell"
: "Logg inn skall"

, "Windows"
: "Windows"

, "Home Drive"
: "Hjemme Stasjon"

, "never logged in"
: "aldri logget på"

, "Home Path"
: "Hjemme Sti"

, "never logged off"
: "aldri logget av"

, "Profile Path"
: "Profil Sti"

, "Password Last Set"
: "Passord Sist Satt"

, "never"
: "aldri"

, "Logon Script"
: "Logg inn Skript"

, "Password Can Change"
: "Passord Kan Endres"

, "not set"
: "ikke satt"

, "Kick Off Time"
: "Utkastelses Tid"

, "Filesystem Quota"
: ""

, "Quota"
: "Kvote"

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Informasjon"

, "Last Login"
: "Siste logg inn"

, "Forward Only"
: "Kun Videresending"

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Legg til en alias adresse..."

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: "Passord bekreftelse"

, "Repeat password"
: "Gjenta passord"

, "Ok"
: "Ok"

, "Account"
: "Konto"

, "Password"
: "Passord"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "aktivert"

, "disabled"
: "deaktivert"

, "expired"
: "Utgått"

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: "vet ikke"

, "Password set"
: "Passord satt"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "Fil server"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "PC"
 ,"PC'er"

]
, "Please wait"
: "Vennligst vent"

, "Updating Memberships"
: "Oppdaterer Medlemskap"

, "Could not save role."
: "Klarte ikke å lagre rolle."

, "Please fix the errors noted."
: "Vennligst rett felene listet."

, "Deleting role..."
: "Sletter rolle..."

, "Rights"
: "Rettigheter"

, "Members"
: "Medlemmer"

, "Role Name"
: "Rolle Navn"

, "Transferring {0}..."
: ""

, "Role"
: ""

, "Add New Role"
: "Legg til Ny Rolle"

, "Edit Role \"{0}\""
: "Rediger Rolle \"{0}\""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "Oppdaterer Overskrift"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Tillatte Contekster"

, "Context"
: "Contekst"

, "Account Rights"
: "Konto Rettigheter"

, "View"
: "Vis"

, "Use"
: "Bruk"

, "Tag Name"
: "Overskrift Navn"

, "Tag"
: ""

, "Add New Tag"
: "Legg til Ny Overskrift"

, "Edit Tag \"{0}\""
: "Rediger Overskrift \"{0}\""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0} Instillinger"

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Viser program {0} - {1} of {2}"

, "No applications to display"
: "Ingen program å vise"

, "Version"
: "Versjon"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""

































, "ImportExportDefinition"
: ""

, "Application"
: ""

, "User"
: "Bruker"

, "Access Log"
: ""

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: ""

, "Group"
: ""

, "Samba User"
: "Samba Bruker"

, "Email User"
: "E-post Bruker"

, "Computer"
: "PC"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
